import React, { FC } from 'react';
import {
  Dialog,
  DialogActions,
  DialogContent,
  DialogContentText,
  DialogTitle,
  Button,
} from '@material-ui/core';
import { setReservation } from 'api/setReservation';
import { useReservations } from 'hooks/useReservations';
import { SubmitHandler, useForm } from 'react-hook-form';
import { InputField } from 'components/Auth/InputField/InputField';
import { SeniorSearch } from 'components/Dashboard/ReservationPage/Reservation/SeniorSearch';
import { TripStage } from './Reservation/TripStage';
import { InsertReservationProps } from './Reservation/InsertReservationProps';

type ReservationDialogProps = {
  handleClose: () => void;
  isOpen: boolean;
};
export const ReservationDialog: FC<ReservationDialogProps> = ({
  handleClose,
  isOpen,
}: ReservationDialogProps) => {
  const { control, handleSubmit } = useForm<InsertReservationProps>({
    mode: 'onSubmit',
  });

  const onSubmit: SubmitHandler<InsertReservationProps> = (
    reservation: InsertReservationProps,
  ) => {
    console.log(reservation);
    setReservation(reservation);
    handleClose();
  };

  return (
    <div data-testid="ReservationDialog">
      <Dialog
        open={isOpen}
        onClose={handleClose}
        aria-labelledby="form-dialog-title"
      >
        <form onSubmit={handleSubmit(onSubmit)} data-testid="Form">
          <DialogTitle id="form-dialog-title">Book New Reservation</DialogTitle>
          <DialogContent>
            <DialogContentText>
              Write here below the details of your next reservation
            </DialogContentText>

            <SeniorSearch control={control} />

            <InputField
              name="number"
              label="Phone number"
              type="tel"
              control={control}
            />
            <InputField
              name="estimatedBeAt"
              label="Destination"
              type="text"
              control={control}
            />

            <TripStage control={control} />
          </DialogContent>
          <DialogActions>
            <Button onClick={handleClose} color="primary">
              Cancel
            </Button>
            <Button type="submit" fullWidth variant="contained" color="primary">
              Insert
            </Button>
          </DialogActions>
        </form>
      </Dialog>
    </div>
  );
};
